==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/domain/impl/BridgeParameterSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.domain.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.domain.BridgeParameter;
import io.ciera.tool.sql.ooaofooa.domain.BridgeParameterSet;
import io.ciera.tool.sql.ooaofooa.domain.BridgeSet;
import io.ciera.tool.sql.ooaofooa.domain.DataTypeSet;
import io.ciera.tool.sql.ooaofooa.domain.DimensionsSet;
import io.ciera.tool.sql.ooaofooa.domain.impl.BridgeParameterSetImpl;
import io.ciera.tool.sql.ooaofooa.domain.impl.BridgeSetImpl;
import io.ciera.tool.sql.ooaofooa.domain.impl.DataTypeSetImpl;
import io.ciera.tool.sql.ooaofooa.domain.impl.DimensionsSetImpl;
import io.ciera.tool.sql.ooaofooa.message.BridgeArgumentSet;
import io.ciera.tool.sql.ooaofooa.message.impl.BridgeArgumentSetImpl;
import io.ciera.tool.sql.ooaofooa.value.ParameterValueSet;
import io.ciera.tool.sql.ooaofooa.value.impl.ParameterValueSetImpl;

import java.util.Arrays;
import java.util.List;


public class BridgeParameterSetImpl extends InstanceSet<BridgeParameterSet,BridgeParameter> implements BridgeParameterSet {

    // attributes
    @Override
    public void setDimensions( String m_Dimensions ) throws XtumlException {
        for ( BridgeParameter bridgeparameter : this ) bridgeparameter.setDimensions( m_Dimensions );
    }
    @Override
    public void setBy_Ref( int m_By_Ref ) throws XtumlException {
        for ( BridgeParameter bridgeparameter : this ) bridgeparameter.setBy_Ref( m_By_Ref );
    }
    @Override
    public void setBParm_ID( UniqueId m_BParm_ID ) throws XtumlException {
        for ( BridgeParameter bridgeparameter : this ) bridgeparameter.setBParm_ID( m_BParm_ID );
    }
    @Override
    public void setDT_ID( UniqueId ref_DT_ID ) throws XtumlException {
        for ( BridgeParameter bridgeparameter : this ) bridgeparameter.setDT_ID( ref_DT_ID );
    }
    @Override
    public void setBrg_ID( UniqueId ref_Brg_ID ) throws XtumlException {
        for ( BridgeParameter bridgeparameter : this ) bridgeparameter.setBrg_ID( ref_Brg_ID );
    }
    @Override
    public void setPrevious_BParm_ID( UniqueId ref_Previous_BParm_ID ) throws XtumlException {
        for ( BridgeParameter bridgeparameter : this ) bridgeparameter.setPrevious_BParm_ID( ref_Previous_BParm_ID );
    }
    @Override
    public void setName( String m_Name ) throws XtumlException {
        for ( BridgeParameter bridgeparameter : this ) bridgeparameter.setName( m_Name );
    }
    @Override
    public void setDescrip( String m_Descrip ) throws XtumlException {
        for ( BridgeParameter bridgeparameter : this ) bridgeparameter.setDescrip( m_Descrip );
    }


    // selections
    @Override
    public BridgeArgumentSet R1014_represents_BridgeArgument() throws XtumlException {
        BridgeArgumentSet bridgeargumentset = new BridgeArgumentSetImpl();
        for ( BridgeParameter bridgeparameter : this ) bridgeargumentset.addAll( bridgeparameter.R1014_represents_BridgeArgument() );
        return bridgeargumentset;
    }
    @Override
    public BridgeSet R21_contains_Bridge() throws XtumlException {
        BridgeSet bridgeset = new BridgeSetImpl();
        for ( BridgeParameter bridgeparameter : this ) bridgeset.add( bridgeparameter.R21_contains_Bridge() );
        return bridgeset;
    }
    @Override
    public DataTypeSet R22_is_defined_by_DataType() throws XtumlException {
        DataTypeSet datatypeset = new DataTypeSetImpl();
        for ( BridgeParameter bridgeparameter : this ) datatypeset.add( bridgeparameter.R22_is_defined_by_DataType() );
        return datatypeset;
    }
    @Override
    public DimensionsSet R49_may_have_Dimensions() throws XtumlException {
        DimensionsSet dimensionsset = new DimensionsSetImpl();
        for ( BridgeParameter bridgeparameter : this ) dimensionsset.addAll( bridgeparameter.R49_may_have_Dimensions() );
        return dimensionsset;
    }
    @Override
    public BridgeParameterSet R55_precedes_BridgeParameter() throws XtumlException {
        BridgeParameterSet bridgeparameterset = new BridgeParameterSetImpl();
        for ( BridgeParameter bridgeparameter : this ) bridgeparameterset.add( bridgeparameter.R55_precedes_BridgeParameter() );
        return bridgeparameterset;
    }
    @Override
    public BridgeParameterSet R55_succeeds_BridgeParameter() throws XtumlException {
        BridgeParameterSet bridgeparameterset = new BridgeParameterSetImpl();
        for ( BridgeParameter bridgeparameter : this ) bridgeparameterset.add( bridgeparameter.R55_succeeds_BridgeParameter() );
        return bridgeparameterset;
    }
    @Override
    public ParameterValueSet R831_ParameterValue() throws XtumlException {
        ParameterValueSet parametervalueset = new ParameterValueSetImpl();
        for ( BridgeParameter bridgeparameter : this ) parametervalueset.addAll( bridgeparameter.R831_ParameterValue() );
        return parametervalueset;
    }


    @Override
    public BridgeParameter nullElement() {
        return BridgeParameterImpl.EMPTY_BRIDGEPARAMETER;
    }

    @Override
    public BridgeParameterSet emptySet() {
      return new BridgeParameterSetImpl();
    }

    @Override
    public BridgeParameterSet value() {
        return this;
    }

    @Override
    public List<BridgeParameter> elements() {
        BridgeParameter[] elements = toArray(new BridgeParameter[0]);
        Arrays.sort(elements, (a, b) -> {
            try {
                return a.getName().compareTo(b.getName());
            } catch (XtumlException e) { return 0; }
        });
        return Arrays.asList(elements);
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/domain/impl/BridgeParameterSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.domain.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.domain.BridgeParameter;
import io.ciera.tool.sql.ooaofooa.domain.BridgeParameterSet;
import io.ciera.tool.sql.ooaofooa.domain.BridgeSet;
import io.ciera.tool.sql.ooaofooa.domain.DataTypeSet;
import io.ciera.tool.sql.ooaofooa.domain.DimensionsSet;
import io.ciera.tool.sql.ooaofooa.domain.impl.BridgeParameterSetImpl;
import io.ciera.tool.sql.ooaofooa.domain.impl.BridgeSetImpl;
import io.ciera.tool.sql.ooaofooa.domain.impl.DataTypeSetImpl;
import io.ciera.tool.sql.ooaofooa.domain.impl.DimensionsSetImpl;
import io.ciera.tool.sql.ooaofooa.message.BridgeArgumentSet;
import io.ciera.tool.sql.ooaofooa.message.impl.BridgeArgumentSetImpl;
import io.ciera.tool.sql.ooaofooa.value.ParameterValueSet;
import io.ciera.tool.sql.ooaofooa.value.impl.ParameterValueSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class BridgeParameterSetImpl extends InstanceSet<BridgeParameterSet,BridgeParameter> implements BridgeParameterSet {

    public BridgeParameterSetImpl() {
    }

    public BridgeParameterSetImpl(Comparator<? super BridgeParameter> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setName( String m_Name ) throws XtumlException {
        for ( BridgeParameter bridgeparameter : this ) bridgeparameter.setName( m_Name );
    }
    @Override
    public void setBParm_ID( UniqueId m_BParm_ID ) throws XtumlException {
        for ( BridgeParameter bridgeparameter : this ) bridgeparameter.setBParm_ID( m_BParm_ID );
    }
    @Override
    public void setDimensions( String m_Dimensions ) throws XtumlException {
        for ( BridgeParameter bridgeparameter : this ) bridgeparameter.setDimensions( m_Dimensions );
    }
    @Override
    public void setDescrip( String m_Descrip ) throws XtumlException {
        for ( BridgeParameter bridgeparameter : this ) bridgeparameter.setDescrip( m_Descrip );
    }
    @Override
    public void setPrevious_BParm_ID( UniqueId ref_Previous_BParm_ID ) throws XtumlException {
        for ( BridgeParameter bridgeparameter : this ) bridgeparameter.setPrevious_BParm_ID( ref_Previous_BParm_ID );
    }
    @Override
    public void setBy_Ref( int m_By_Ref ) throws XtumlException {
        for ( BridgeParameter bridgeparameter : this ) bridgeparameter.setBy_Ref( m_By_Ref );
    }
    @Override
    public void setBrg_ID( UniqueId ref_Brg_ID ) throws XtumlException {
        for ( BridgeParameter bridgeparameter : this ) bridgeparameter.setBrg_ID( ref_Brg_ID );
    }
    @Override
    public void setDT_ID( UniqueId ref_DT_ID ) throws XtumlException {
        for ( BridgeParameter bridgeparameter : this ) bridgeparameter.setDT_ID( ref_DT_ID );
    }


    // selections
    @Override
    public BridgeArgumentSet R1014_represents_BridgeArgument() throws XtumlException {
        BridgeArgumentSet bridgeargumentset = new BridgeArgumentSetImpl();
        for ( BridgeParameter bridgeparameter : this ) bridgeargumentset.addAll( bridgeparameter.R1014_represents_BridgeArgument() );
        return bridgeargumentset;
    }
    @Override
    public BridgeSet R21_contains_Bridge() throws XtumlException {
        BridgeSet bridgeset = new BridgeSetImpl();
        for ( BridgeParameter bridgeparameter : this ) bridgeset.add( bridgeparameter.R21_contains_Bridge() );
        return bridgeset;
    }
    @Override
    public DataTypeSet R22_is_defined_by_DataType() throws XtumlException {
        DataTypeSet datatypeset = new DataTypeSetImpl();
        for ( BridgeParameter bridgeparameter : this ) datatypeset.add( bridgeparameter.R22_is_defined_by_DataType() );
        return datatypeset;
    }
    @Override
    public DimensionsSet R49_may_have_Dimensions() throws XtumlException {
        DimensionsSet dimensionsset = new DimensionsSetImpl();
        for ( BridgeParameter bridgeparameter : this ) dimensionsset.addAll( bridgeparameter.R49_may_have_Dimensions() );
        return dimensionsset;
    }
    @Override
    public BridgeParameterSet R55_precedes_BridgeParameter() throws XtumlException {
        BridgeParameterSet bridgeparameterset = new BridgeParameterSetImpl();
        for ( BridgeParameter bridgeparameter : this ) bridgeparameterset.add( bridgeparameter.R55_precedes_BridgeParameter() );
        return bridgeparameterset;
    }
    @Override
    public BridgeParameterSet R55_succeeds_BridgeParameter() throws XtumlException {
        BridgeParameterSet bridgeparameterset = new BridgeParameterSetImpl();
        for ( BridgeParameter bridgeparameter : this ) bridgeparameterset.add( bridgeparameter.R55_succeeds_BridgeParameter() );
        return bridgeparameterset;
    }
    @Override
    public ParameterValueSet R831_ParameterValue() throws XtumlException {
        ParameterValueSet parametervalueset = new ParameterValueSetImpl();
        for ( BridgeParameter bridgeparameter : this ) parametervalueset.addAll( bridgeparameter.R831_ParameterValue() );
        return parametervalueset;
    }


    @Override
    public BridgeParameter nullElement() {
        return BridgeParameterImpl.EMPTY_BRIDGEPARAMETER;
    }

    @Override
    public BridgeParameterSet emptySet() {
      return new BridgeParameterSetImpl();
    }

    @Override
    public BridgeParameterSet emptySet(Comparator<? super BridgeParameter> comp) {
      return new BridgeParameterSetImpl(comp);
    }

    @Override
    public BridgeParameterSet value() {
        return this;
    }

    @Override
    public List<BridgeParameter> elements() {
        BridgeParameter[] elements = toArray(new BridgeParameter[0]);
        Arrays.sort(elements, (a, b) -> {
            try {
                return a.getName().compareTo(b.getName());
            } catch (XtumlException e) { return 0; }
        });
        return Arrays.asList(elements);
    }

}
